@@ -41,8 +41,6 @@
 
 #define KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KWAYLANDCLIENT_NO_DEPRECATED) && !defined(KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KWAYLANDCLIENT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED
-#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KWAYLANDCLIENT_DEPRECATED
-#  define KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
